<?php
/**
* Performs logics to place the proper article, then place 'an' in front
*
* @param string $word The variable for the word which will be modified
*
* @return string Returns a string with the proper article
*/
function addArticle($word) {

	//if the first letter is a vowel
	if(ereg("[AEIOUaeiou]",$word{0}))
		return "an $word";
	else
		return "a $word";
}
/**
* Returns random string of length $num made up of charcters in $chars
*
* @param int $num Num must equal 8, determines the length
* @param int $chars List of characters which the string can be made of
*
* @return string Word created with length $num and characters $chars
*/
function getRandom($num=8,$chars='abcdefghijklmnopqrstuvwxyz0123456789') {

	//if specified, the list of characters generated will be set to 23456789bcdfghjkmnpqrstvwxyz
	if($chars=='distinguishable' || $chars=="distinct")
		$chars = "23456789bcdfghjkmnpqrstvwxyz";
	//create a random string for the length of $num
	for($C=0;$C<$num;$C++)
	{
		$word .= $chars{rand(0,strlen($chars)-1)};
	}
	return $word;
}
/**
* Appends $add to end of $arr, recursively if $add is an array
*
* @param array $arr Array of vales
* @param string|int $add Value to be added to the end of the array
*/
function addToArray(&$arr,$add) {
	if(is_array($add)) {
		foreach($add as $value) {
			$arr[] = $value;
		}
	}
	else
		$arr[] = $add;
}
/**
* Returns time in the format January 23, 2008
*
* @param int $time The time to be formatted
*
* @return string The formatted returned date
*/
function formatDate($time) {
	return date("F d, Y",$time);
}
/**
* Returns a formatted phone number
*
* @param int $num The number to edit
*
* @return string Returns the string with formatting edits depending on length
*/
function phoneFormat($num) {
	if (strlen($num) == 10) {
		return preg_replace("/([0-9a-zA-Z]{3})([0-9a-zA-Z]{3})([0-9a-zA-Z]{4})/", "$1-$2-$3", $num);
	} 
	elseif (strlen($num) == 11) {
		return preg_replace("/([0-9a-zA-Z]{1})([0-9a-zA-Z]{3})([0-9a-zA-Z]{3})([0-9a-zA-Z]{4})/", "$1-$2-$3-$4", $num);
	}
	else
		return $num;
}
/**
* Strips all non-digits from a phone number
*
* @param string $num The input phone number to be edited
*
* @return string Returns the stripped phone number
*/
function stripphone($num) {
	return preg_replace("/[^0-9]*/","",$num);	
}
/**
* Returns the date in the format 12/31
*
* @param string $time Date to be formatted
*
* @return string Returns formatted date
*/
function getD($time) {
	return date("n/j",$time);
}
/**
* Returns the time in the format 3:45 PM
*
* @param string $time Input for time to be formatted
*
* @return string Returns formatted time
*/
function getT($time)
{
	return date("g:i A",$time);
}
/**
* Converts a mysql datetime to a unix timestamp
*
* @param string $str String holding values to be formatted
*
* @return int Returns the converted string
*/
function datetimetounix($str) {
list($date, $time) = explode(' ', $str);
list($year, $month, $day) = explode('-', $date);
list($hour, $minute, $second) = explode(':', $time);
return mktime($hour, $minute, $second, $month, $day, $year);
}
/**
* Converts a unix timestamp to a mysql datetime
*
* @param int $time Takes a string in a unix timestamp
*
* @return string Returns the string in mysql datetime format
*/
function unixtodatetime($time) {
	return date("Y-m-d H:i:s",$time);
}
/**
* Returns a formatted time 12/31/08 4:54 PM
*
* @param string $time Input date and time
*
* @return string Returns the formatted time
*/
function getDateTime($time) {
	return date("n/j/y g:i A",$time);
}
/**
* Converts seconds to minutes:seconds (ie. 123 becomes 2:03)
*
* @param string $time Imput time amount 
*
* @param string Returns time formatted in 2:03 format
*/
function secondsToTime($time) {
	$secs = $time%60;
	$mins = ($time-$secs)/60;
	if($secs<10)
		$secs = "0".$secs;
	return "$mins:$secs";
}
/**
* Converts an array to url
*
* @param array $array Array to be converted
* @param string $delimiter String to be removed from array
*
* @return string Returns encoded url
*/
function arraytourl($array,$delimiter="|") {
	return urlencode(str_replace('/','@',implode($delimiter,$array)));
}
/**
* Decodes url to array
*
* @param string $url Url string to be converted to array
* @param string $delimiter 
*
* @return array 
*/
function urltoarray($url,$delimiter="|") {
	return explode($delimiter,str_replace('@','/',urldecode($url)));
}

/**
* Returns the global variable with the passed name
*
* @param string $string The name of the variable (ie. "MyVar")
* @return mixed The variable (ie $MyVar)
*/
function getVar($string) {
	global ${$string};
	return ${$string};
}

/**
* Tells if application is in debug mode
*
* @return boolean Returns True if in debug mode, false if not
*/
function in_debug_mode() {
	return (get_debug_level() > 0);
}

function get_debug_level() {
	if(defined('DEBUG_LEVEL')) return DEBUG_LEVEL;
	else return $_REQUEST['debug'];
}

/**
* Prints a debug message if application is in debug mode
*
* @param string $string String to print
* @param int $level The level of importance to print
*/
function print_debug($string,$level=1) {
	$current_level = get_debug_level();
	if($level <= $current_level) echo "<div style='color:#666; font-style:italic'>$string</div>";	
}

/**
* Returns an alert widget 
*
* @params string $str The string to be contained in the alert widget
*
* @return string The alert widget
*/
function alert($str) {
	return	"<div class='ui-widget'>
				<div class='ui-state-error ui-corner-all' style='padding: 4px 10px;'> 
					<div class='ui-icon ui-icon-alert' style='display:block; float: left; margin-right:.2em; margin-top:3px;'>&nbsp;</div> 
					<div style='margin-left:20px;'>$str</div>
				</div>
			</div>";
}
/**
* Returns a notice widget 
*
* @params string $str The string to be contained in the notice widget
*
* @return string The complete notice widget.
*/
function notice($str) {
	return 	"<div class='ui-widget'>
				<div class='ui-state-highlight ui-corner-all' style='padding: 4px 10px;'> 
					<div class='ui-icon ui-icon-info' style='display:block; float: left; margin-right:.2em; margin-top:3px;'>&nbsp;</div> 
					<div style='margin-left:20px;'>$str</div>
				</div>
			</div>";

}

function add_log_entry($text) {
	$user_id = $_SESSION['userid'];
	
	//get log file
	list($date,$time) = explode(" ",unixtodatetime(time()),2);
	$filename = 'log_'.$date.'.log';
	
	$text = "$time::$text::$user_id";
	
	file_put_contents("logs/".$filename,"\n".$text,FILE_APPEND);
}

function include_header($file='header') {
	global $linkpref,$site_root,$orig_siteroot,$language,$path,$current_path,$footer_file,$template_level;
	global $title, $meta, $hidetitle, $title_prepend;
	
	if(empty($footer_file) && empty($template_level)) {
		require_once "includes/before_header.php";
		if($file==='header' && $_SESSION['mobile'] && file_exists(SITE_FOLDER.'cms/pages/header_mobile.php')) require_once SITE_FOLDER.'cms/pages/header_mobile.php';
		elseif($file==='cms_header' && $_SESSION['mobile']) require_once 'includes/cms_header.mobile.php';
		elseif($file==='header') require_once SITE_FOLDER."cms/pages/header.php";
		else require_once "includes/{$file}.php";
	}

	if(empty($footer_file) && $file=='header') $footer_file = 'footer';
}
/**
* Method for using the footer formatting 
*/
function footer() {
	global $linkpref,$site_root,$orig_siteroot,$language,$template_level,$footer_file;
	
	//determine which footer to include
	if($_SESSION['mobile'] && $footer_file==='footer' && file_exists(SITE_FOLDER.'cms/pages/footer_mobile.php')) require_once(SITE_FOLDER.'cms/pages/footer_mobile.php');
	elseif($footer_file && $footer_file==='footer') require_once(SITE_FOLDER."cms/pages/footer.php");
	elseif($footer_file) require_once("includes/$footer_file.php");
	elseif($template_level === 'full') require_once(SITE_FOLDER."cms/pages/footer.php");
	elseif($template_level === 'html') require_once "includes/template-end.php";
	else require_once "includes/base-end.php";
}

function getOptions($text,$pattern) {
	return CMS::parse($text,$pattern);
}

function loadCMS($page,$element) {
	return CMS::load($page,$element);
}

function cmsLogin() {
	global $site_root;
	if($_SESSION['cms_logged_in']) return true;
	else {
		header("Location: {$site_root}cms/login/");
		exit();
	}
}

//recursively remove a directory
 function rrmdir($dir) {
   if (is_dir($dir)) {
     $objects = scandir($dir);
     foreach ($objects as $object) {
       if ($object != "." && $object != "..") {
         if (filetype($dir."/".$object) == "dir") rrmdir($dir."/".$object); else unlink($dir."/".$object);
       }
     }
     reset($objects);
     return rmdir($dir);
   }
 }
 
function csv_to_array($csv) {
	$rows = explode("\n",trim($csv));
	$return = array();
	foreach($rows as $row) {
		$temp = explode('","',$row);
		foreach($temp as &$t) {
			$t = trim($t,"\" \n\t\r");
		}
		$return[] = $temp;
	}
	return $return;
}

function translate($phrase) {
	global $language, $default_language;
	$language_var = str_replace('-','_',$language) . '_language';
	$default_var = str_replace('-','_',$defualt_language) . '_language';
	
	
	//load language file
	if($language && $language !== 'en-us' && file_exists('languages/'.$language.'.php')) {
		global ${$language_var};
		require_once('languages/'.$language.'.php');
		
		//if phrase exists
		if(isset(${$language_var}[$phrase])) {
			return ${$language_var}[$phrase];
		}
	}
	//load default language file
	if($default_language && $default_language !== 'en-us' && file_exists('languages/'.$default_language.'.php')) {
		global ${$default_var};
		require_once('languages/'.$default_language.'.php');
		
		//if phrase exists
		if(isset(${$default_var}[$phrase])) {
			return ${$default_var}[$phrase];
		}
	}
	/*
	//load en-us file
	if($default_language != 'en-us' && $language!= 'en-us' && file_exists('languages/en-us.php')) {
		global $en_us_language;
		require_once('languages/en-us.php');
		
		//if phrase exists
		if(isset($en_us_language[$phrase])) {
			return $en_us_language[$phrase];
		}
	}
	*/
	
	//no translation found
	return $phrase;
}
?>