<?php
session_start();

//basic server configuration file
require "server/server.php";

//stores original, unaltered site_root
$orig_siteroot = $site_root;

//shortcut for viewing phpinfo()
if($_REQUEST['phpinfo'] === 'true' && defined('DEBUG_LEVEL') && DEBUG_LEVEL>0) {
	phpinfo();
	exit();
}

//url routing rules
require "includes/routes.php";

//access control
require "includes/access_control.php";
if($_SESSION['type']) $acl = $acl_rules[$_SESSION['type']];
else $acl = array();

$NO_DATABASE = true;

//get current url (ie. /cms/index.php/cms/edit/home/main_text/)
$current_path = isset($_REQUEST['uri'])? $_REQUEST['uri'] : (empty($_SERVER['ORIG_PATH_INFO']) ? $_SERVER['PHP_SELF'] : $_SERVER['ORIG_PATH_INFO']);

//if http:// is in current_path, reload page with trailing slash (fixes problem with some apache setups)
if(strstr($current_path,'http://') || strstr($current_path,'https://')) {
	echo "<script type='text/javascript'>window.location.href = window.location.href + '/';</script>";
	exit();
}

//remove site root  from current path (ie. cms/edit/home/main_text/)
$temp = array('/index.php(\/)?/');
if($site_root && $site_root != '/')	array_unshift($temp,"/^".preg_replace('/\//','\/',$site_root)."(\/)?/");
$current_path = preg_replace($temp,'',$current_path);
if($current_path{0}=='/') $current_path = substr($current_path,1);
if(substr($current_path,-1)!='/') {
	$current_path .= '/';
}
if($current_path=='/') $current_path = '';


//array of path parts
$path_parts = explode("/",$current_path);

//remove empty elements from path
foreach($path_parts as $key=>$part) {
	if(empty($part)) {
		unset($path_parts[$key]);
	}
}

//get path depth (used for generating linkpref)
$path_depth = count($path_parts);

//add to path_depth if mod rewrite isn't used
if(!$use_mod_rewrite) $path_depth ++;

//generate linkpref
$linkpref = "";
for($i=0;$i<$path_depth;$i++) $linkpref .= "../";

//remove country and language code from url
if(preg_match("/^[a-z]{2}(\-[a-z]{2})?\//",$current_path) && substr($current_path,0,3)!=='js/') {
	$current_path = explode('/',$current_path);
	$language = array_shift($current_path);
	$site_root.=$language.'/';
	$current_path = implode('/',$current_path);
}
else $language = 'en-us';

//mobile detection
if($_REQUEST['mobile']==='false') {
	$_SESSION['mobile'] = false;
}
elseif($_REQUEST['mobile']==='0') {
	$_SESSION['mobile'] = 0;
}
elseif($_REQUEST['mobile']) {
	$_SESSION['mobile'] = true;
}
elseif(!isset($_SESSION['mobile'])) {
	include 'includes/mobilebrowserdetect.php';
	$_SESSION['mobile'] = mobile_detect();
}

//captcha image, skip rest
if(trim($current_path,'/') === 'images/captcha') {
	include 'images/captcha.php';
	exit();
}

//includes
require "includes/base.php";
require "includes/functions.php";

if(!$NO_DATABASE)
require "includes/mysql.php";

//define url rerouting rules
$router = new Router($routing_rules);


//load homepage if path is empty
if(empty($current_path)||$current_path=='index.php'||$current_path=='/') echo CMS::loadPage('home.php');
	
//get homepage based on routing rules and current url
else {
	//get file to load from router
	$rawpath = $router->getPath($current_path);
	$path = SITE_FOLDER.$rawpath;
	
	//load admin page
	if(!empty($rawpath) && file_exists($path)) include $path;
	
	//load site page
	elseif($temp = CMS::loadPage($rawpath)) {
		echo $temp;
	}
	
	//load file_not_found page
	else {
		//debug routing information
		print_debug(print_r(array(
			'path parts'=>$path_parts,
			'site_root'=>$site_root,
			'current_path'=>$current_path,
			'file loaded'=>$path
		),true),1);
		echo CMS::loadPage('page_not_found.php');
	}
}
?>